# Réinitialiser les feedbacks

*Astuce : L'effet de ce plugin est le même que présenter un item FEEDBACK avec une durée de 0 ms.*

Si vous ne réinitialisez pas les variables de feedback, vous pouvez confondre votre feedback avec les réponses qui ne sont pas pertinentes pour la tâche. Par exemple, appuyer sur une touche pendant les consignes peut perturber le premier bloc de l'expérimentation. Vous devez donc ré-initialiser les variables de feedback aux moments appropriés.

Ce plugin réinitialise les variables suivants (remise à 0) :
- `total_response_time`
- `total_response`
- `acc`
- `accuracy`
- `avg_rt`
- `average_response_time`

Pour plus d'informations, rendez-vous sur :

- <http://osdoc.cogsci.nl/3.2/manual/stimuli/visual/>
